summaryrefslogtreecommitdiffstats
path: root/krecipes/src/widgets/categorylistview.h
diff options
context:
space:
mode:
Diffstat (limited to 'krecipes/src/widgets/categorylistview.h')
-rw-r--r--krecipes/src/widgets/categorylistview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/krecipes/src/widgets/categorylistview.h b/krecipes/src/widgets/categorylistview.h
index 630653a..98a32be 100644
--- a/krecipes/src/widgets/categorylistview.h
+++ b/krecipes/src/widgets/categorylistview.h
@@ -19,7 +19,7 @@
#include "datablocks/elementlist.h"
-class KPopupMenu;
+class TDEPopupMenu;
class RecipeDB;
class CategoryTree;
@@ -123,7 +123,7 @@ protected:
virtual void load( int limit, int offset );
/** so that it allows dropping into
* subchildren that aren't expandable. The code is taken from KDE's KListView with
* one line commented out.
*/
void findDrop( const TQPoint &pos, TQListViewItem *&parent, TQListViewItem *&after )
@@ -225,7 +225,7 @@ protected:
private slots:
void preparePopup();
- void showPopup( KListView *, TQListViewItem *, const TQPoint & );
+ void showPopup( TDEListView *, TQListViewItem *, const TQPoint & );
void createNew();
void remove
@@ -243,7 +243,7 @@ private slots:
private:
bool checkBounds( const TQString &name );
- KPopupMenu *kpop;
+ TDEPopupMenu *kpop;
TQListViewItem *clipboard_item;
TQListViewItem *clipboard_parent;
@@ -123,7 +123,7 @@ protected:
virtual void load( int limit, int offset );
/** so that it allows dropping into
- * subchildren that aren't expandable. The code is taken from KDE's KListView with
+ * subchildren that aren't expandable. The code is taken from KDE's TDEListView with
* one line commented out.
*/